<?php
/**
 * Plugin Name: WooCommerce Counter with shortcodes (EasyToolsWP)
 * Description: A simple plugin to count products and customers in WooCommerce.
 * Version: 1.1
 * Author: EasyToolsWP
 */

// Ensure WooCommerce is active
if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {

    // Shortcode to count all products
    function etwp_counter_products() {
        $count = wp_count_posts('product')->publish;
        return $count;
    }
    add_shortcode('etwp_counter_products', 'etwp_counter_products');

    // Shortcode to count products in a specific category
    function etwp_counter_products_in_category($atts) {
        $atts = shortcode_atts(array(
            'id' => '',
        ), $atts, 'etwp_counter_products_in_category');
        
        if (empty($atts['id'])) {
            return 0;
        }

        $args = array(
            'post_type' => 'product',
            'posts_per_page' => -1,
            'tax_query' => array(
                array(
                    'taxonomy' => 'product_cat',
                    'field'    => 'id',
                    'terms'    => $atts['id'],
                ),
            ),
            'fields' => 'ids',
        );

        $query = new WP_Query($args);
        $count = $query->found_posts;

        return $count;
    }
    add_shortcode('etwp_counter_products_in_category', 'etwp_counter_products_in_category');

    // Shortcode to count products in a specific tag
    function etwp_counter_products_in_tag($atts) {
        $atts = shortcode_atts(array(
            'id' => '',
        ), $atts, 'etwp_counter_products_in_tag');
        
        if (empty($atts['id'])) {
            return 0;
        }

        $args = array(
            'post_type' => 'product',
            'posts_per_page' => -1,
            'tax_query' => array(
                array(
                    'taxonomy' => 'product_tag',
                    'field'    => 'id',
                    'terms'    => $atts['id'],
                ),
            ),
            'fields' => 'ids',
        );

        $query = new WP_Query($args);
        $count = $query->found_posts;

        return $count;
    }
    add_shortcode('etwp_counter_products_in_tag', 'etwp_counter_products_in_tag');

    // Shortcode to count all customers
    function etwp_counter_customers() {
        $args = array(
            'role__in' => array('customer', 'subscriber'), // include both customers and subscribers
            'fields' => 'ID',
        );
        $customers = get_users($args);
        return count($customers);
    }
    add_shortcode('etwp_counter_customers', 'etwp_counter_customers');

    // Function to record last login time
    function etwp_record_last_login($login) {
        $user = get_user_by('login', $login);
        update_user_meta($user->ID, 'etwp_last_login', current_time('mysql'));
    }
    add_action('wp_login', 'etwp_record_last_login');

    // Shortcode to count customer logins in the last 30 days
    function etwp_counter_customer_logins_last_30_days() {
        global $wpdb;
        $date_30_days_ago = date('Y-m-d H:i:s', strtotime('-30 days'));

        $login_count = $wpdb->get_var(
            $wpdb->prepare("
                SELECT COUNT(DISTINCT user_id) 
                FROM {$wpdb->prefix}usermeta
                WHERE meta_key = 'etwp_last_login'
                AND meta_value >= %s
            ", $date_30_days_ago)
        );

        return $login_count;
    }
    add_shortcode('etwp_counter_customer_logins_last_30_days', 'etwp_counter_customer_logins_last_30_days');
}
?>